summaryrefslogtreecommitdiffstats
path: root/style/src/pick_list.rs
diff options
context:
space:
mode:
Diffstat (limited to 'style/src/pick_list.rs')
-rw-r--r--style/src/pick_list.rs4
1 files changed, 2 insertions, 2 deletions
diff --git a/style/src/pick_list.rs b/style/src/pick_list.rs
index 877a58da..11e13b01 100644
--- a/style/src/pick_list.rs
+++ b/style/src/pick_list.rs
@@ -8,8 +8,8 @@ pub struct Appearance {
pub text_color: Color,
/// The placeholder [`Color`] of the pick list.
pub placeholder_color: Color,
- /// The accessory content [`Color`] of the pick list.
- pub accessory_content_color: Color,
+ /// The handle [`Color`] of the pick list.
+ pub handle_color: Color,
/// The [`Background`] of the pick list.
pub background: Background,
/// The border radius of the pick list.